"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.v0.environments.configuration_pb2
import qwak.administration.v0.environments.environment_pb2
import qwak.administration.v0.environments.personalization_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    PERSONALIZATION_FIELD_NUMBER: builtins.int
    environment_name: builtins.str
    """Environment name to be created. For example - Dev, Prod, and QA."""
    tenant_id: builtins.str
    """The tenant ID the environment is configured for (changed to be account id)"""
    account_id: builtins.str
    """The account ID the environment is configured for"""
    cluster_id: builtins.str
    """The Qwak Cluster the environment will deploy in."""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """Environment configuration"""
    @property
    def personalization(self) -> qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization:
        """Environment personalization"""
    def __init__(
        self,
        *,
        environment_name: builtins.str = ...,
        tenant_id: builtins.str = ...,
        account_id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
        personalization: qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "cluster_id", b"cluster_id", "configuration", b"configuration", "environment_name", b"environment_name", "personalization", b"personalization", "tenant_id", b"tenant_id"]) -> None: ...

global___CreateEnvironmentRequest = CreateEnvironmentRequest

class CreateEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Created environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___CreateEnvironmentResponse = CreateEnvironmentResponse

class UpdateEnvironmentConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id to update"""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """New environment configuration"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "environment_id", b"environment_id"]) -> None: ...

global___UpdateEnvironmentConfigurationRequest = UpdateEnvironmentConfigurationRequest

class UpdateEnvironmentConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateEnvironmentConfigurationResponse = UpdateEnvironmentConfigurationResponse

class UpdateEnvironmentPersonalizationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PERSONALIZATION_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """The environment id to update"""
    @property
    def personalization(self) -> qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization:
        """New environment configuration"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        personalization: qwak.administration.v0.environments.personalization_pb2.EnvironmentPersonalization | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["personalization", b"personalization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "personalization", b"personalization"]) -> None: ...

global___UpdateEnvironmentPersonalizationRequest = UpdateEnvironmentPersonalizationRequest

class UpdateEnvironmentPersonalizationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateEnvironmentPersonalizationResponse = UpdateEnvironmentPersonalizationResponse

class GetEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetEnvironmentRequest = GetEnvironmentRequest

class GetEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.v0.environments.environment_pb2.QwakEnvironment:
        """Fetched Environment by the requested ID"""
    def __init__(
        self,
        *,
        environment: qwak.administration.v0.environments.environment_pb2.QwakEnvironment | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___GetEnvironmentResponse = GetEnvironmentResponse

class GetEnvironmentApplicationUserCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetEnvironmentApplicationUserCredentialsRequest = GetEnvironmentApplicationUserCredentialsRequest

class GetEnvironmentApplicationUserCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def credentials(self) -> qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials:
        """The API key for the application user of the requested environment"""
    def __init__(
        self,
        *,
        credentials: qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> None: ...

global___GetEnvironmentApplicationUserCredentialsResponse = GetEnvironmentApplicationUserCredentialsResponse

class SetEnvironmentApplicationUserCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment ID to fetch"""
    @property
    def credentials(self) -> qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials:
        """The API key for the application user of the requested environment"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        credentials: qwak.administration.v0.environments.environment_pb2.EnvironmentApplicationUserCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "environment_id", b"environment_id"]) -> None: ...

global___SetEnvironmentApplicationUserCredentialsRequest = SetEnvironmentApplicationUserCredentialsRequest

class SetEnvironmentApplicationUserCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetEnvironmentApplicationUserCredentialsResponse = SetEnvironmentApplicationUserCredentialsResponse

class ListEnvironmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Filter(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENVIRONMENT_STATUS_FIELD_NUMBER: builtins.int
        environment_status: qwak.administration.v0.environments.environment_pb2.QwakEnvironmentStatus.ValueType
        """Filter based on environment status"""
        def __init__(
            self,
            *,
            environment_status: qwak.administration.v0.environments.environment_pb2.QwakEnvironmentStatus.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["environment_status", b"environment_status"]) -> None: ...

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> global___ListEnvironmentsRequest.Filter: ...
    def __init__(
        self,
        *,
        filter: global___ListEnvironmentsRequest.Filter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListEnvironmentsRequest = ListEnvironmentsRequest

class ListEnvironmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENTS_FIELD_NUMBER: builtins.int
    @property
    def environments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.v0.environments.environment_pb2.QwakEnvironment]:
        """All environments that matched the provided filter"""
    def __init__(
        self,
        *,
        environments: collections.abc.Iterable[qwak.administration.v0.environments.environment_pb2.QwakEnvironment] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environments", b"environments"]) -> None: ...

global___ListEnvironmentsResponse = ListEnvironmentsResponse
