# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bqwak/deployment/alert.proto\x12\x1aqwak.deployment.management\"\xe2\x01\n\tAlertRule\x12\x39\n\nalert_spec\x18\x01 \x01(\x0b\x32%.qwak.deployment.management.AlertSpec\x12S\n\x16notifications_channels\x18\x02 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\x12\x10\n\x08\x61lert_id\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17selected_variation_name\x18\x05 \x01(\t\"\xaa\x02\n\tAlertSpec\x12\x45\n\x10reducer_function\x18\x01 \x01(\x0e\x32+.qwak.deployment.management.ReducerFunction\x12\x41\n\x0e\x65valuator_type\x18\x02 \x01(\x0e\x32).qwak.deployment.management.EvaluatorType\x12\x1f\n\x13\x65valuator_threshold\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x19\n\x11\x65valuation_period\x18\x04 \x01(\x05\x12\x39\n\nalert_type\x18\x05 \x01(\x0e\x32%.qwak.deployment.management.AlertType\x12\x1c\n\x14\x65valuation_threshold\x18\x06 \x01(\x02\"]\n\x17NotificationChannelSpec\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\"\xb1\x01\n\x13NotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\x12V\n\x15notification_settings\x18\x03 \x01(\x0b\x32\x37.qwak.deployment.management.NotificationChannelSettings\"\xb5\x01\n\x1bNotificationChannelSettings\x12\x43\n\x0eslack_settings\x18\x01 \x01(\x0b\x32).qwak.deployment.management.SlackSettingsH\x00\x12I\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32,.qwak.deployment.management.OpsgenieSettingsH\x00\x42\x06\n\x04type\"\x1c\n\rSlackSettings\x12\x0b\n\x03url\x18\x01 \x01(\t\"4\n\x10OpsgenieSettings\x12\x0f\n\x07\x61pi_url\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t*\x82\x01\n\tAlertType\x12\x18\n\x14\x41LERT_TYPE_NOT_VALID\x10\x00\x12\x0e\n\nERROR_RATE\x10\x01\x12\x0e\n\nTHROUGHPUT\x10\x02\x12\x0b\n\x07LATENCY\x10\x03\x12\x0e\n\nLATENCY_90\x10\x04\x12\x0e\n\nLATENCY_95\x10\x05\x12\x0e\n\nLATENCY_99\x10\x06*\xad\x01\n\x0fReducerFunction\x12\x1e\n\x1aREDUCER_FUNCTION_NOT_VALID\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\x12\x07\n\x03SUM\x10\x03\x12\t\n\x05\x43OUNT\x10\x04\x12\x08\n\x04LAST\x10\x05\x12\n\n\x06MEDIAN\x10\x06\x12\x08\n\x04\x44IFF\x10\x07\x12\x0c\n\x08\x44IFF_ABS\x10\x08\x12\x10\n\x0cPERCENT_DIFF\x10\t\x12\x14\n\x10PERCENT_DIFF_ABS\x10\n*I\n\rEvaluatorType\x12\x1c\n\x18\x45VALUATOR_TYPE_NOT_VALID\x10\x00\x12\x0c\n\x08IS_ABOVE\x10\x01\x12\x0c\n\x08IS_BELOW\x10\x02\x42)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')

_ALERTTYPE = DESCRIPTOR.enum_types_by_name['AlertType']
AlertType = enum_type_wrapper.EnumTypeWrapper(_ALERTTYPE)
_REDUCERFUNCTION = DESCRIPTOR.enum_types_by_name['ReducerFunction']
ReducerFunction = enum_type_wrapper.EnumTypeWrapper(_REDUCERFUNCTION)
_EVALUATORTYPE = DESCRIPTOR.enum_types_by_name['EvaluatorType']
EvaluatorType = enum_type_wrapper.EnumTypeWrapper(_EVALUATORTYPE)
ALERT_TYPE_NOT_VALID = 0
ERROR_RATE = 1
THROUGHPUT = 2
LATENCY = 3
LATENCY_90 = 4
LATENCY_95 = 5
LATENCY_99 = 6
REDUCER_FUNCTION_NOT_VALID = 0
MIN = 1
MAX = 2
SUM = 3
COUNT = 4
LAST = 5
MEDIAN = 6
DIFF = 7
DIFF_ABS = 8
PERCENT_DIFF = 9
PERCENT_DIFF_ABS = 10
EVALUATOR_TYPE_NOT_VALID = 0
IS_ABOVE = 1
IS_BELOW = 2


_ALERTRULE = DESCRIPTOR.message_types_by_name['AlertRule']
_ALERTSPEC = DESCRIPTOR.message_types_by_name['AlertSpec']
_NOTIFICATIONCHANNELSPEC = DESCRIPTOR.message_types_by_name['NotificationChannelSpec']
_NOTIFICATIONCHANNEL = DESCRIPTOR.message_types_by_name['NotificationChannel']
_NOTIFICATIONCHANNELSETTINGS = DESCRIPTOR.message_types_by_name['NotificationChannelSettings']
_SLACKSETTINGS = DESCRIPTOR.message_types_by_name['SlackSettings']
_OPSGENIESETTINGS = DESCRIPTOR.message_types_by_name['OpsgenieSettings']
AlertRule = _reflection.GeneratedProtocolMessageType('AlertRule', (_message.Message,), {
  'DESCRIPTOR' : _ALERTRULE,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.AlertRule)
  })
_sym_db.RegisterMessage(AlertRule)

AlertSpec = _reflection.GeneratedProtocolMessageType('AlertSpec', (_message.Message,), {
  'DESCRIPTOR' : _ALERTSPEC,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.AlertSpec)
  })
_sym_db.RegisterMessage(AlertSpec)

NotificationChannelSpec = _reflection.GeneratedProtocolMessageType('NotificationChannelSpec', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNELSPEC,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannelSpec)
  })
_sym_db.RegisterMessage(NotificationChannelSpec)

NotificationChannel = _reflection.GeneratedProtocolMessageType('NotificationChannel', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNEL,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannel)
  })
_sym_db.RegisterMessage(NotificationChannel)

NotificationChannelSettings = _reflection.GeneratedProtocolMessageType('NotificationChannelSettings', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCHANNELSETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.NotificationChannelSettings)
  })
_sym_db.RegisterMessage(NotificationChannelSettings)

SlackSettings = _reflection.GeneratedProtocolMessageType('SlackSettings', (_message.Message,), {
  'DESCRIPTOR' : _SLACKSETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.SlackSettings)
  })
_sym_db.RegisterMessage(SlackSettings)

OpsgenieSettings = _reflection.GeneratedProtocolMessageType('OpsgenieSettings', (_message.Message,), {
  'DESCRIPTOR' : _OPSGENIESETTINGS,
  '__module__' : 'qwak.deployment.alert_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.OpsgenieSettings)
  })
_sym_db.RegisterMessage(OpsgenieSettings)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _ALERTSPEC.fields_by_name['evaluator_threshold']._options = None
  _ALERTSPEC.fields_by_name['evaluator_threshold']._serialized_options = b'\030\001'
  _ALERTTYPE._serialized_start=1133
  _ALERTTYPE._serialized_end=1263
  _REDUCERFUNCTION._serialized_start=1266
  _REDUCERFUNCTION._serialized_end=1439
  _EVALUATORTYPE._serialized_start=1441
  _EVALUATORTYPE._serialized_end=1514
  _ALERTRULE._serialized_start=60
  _ALERTRULE._serialized_end=286
  _ALERTSPEC._serialized_start=289
  _ALERTSPEC._serialized_end=587
  _NOTIFICATIONCHANNELSPEC._serialized_start=589
  _NOTIFICATIONCHANNELSPEC._serialized_end=682
  _NOTIFICATIONCHANNEL._serialized_start=685
  _NOTIFICATIONCHANNEL._serialized_end=862
  _NOTIFICATIONCHANNELSETTINGS._serialized_start=865
  _NOTIFICATIONCHANNELSETTINGS._serialized_end=1046
  _SLACKSETTINGS._serialized_start=1048
  _SLACKSETTINGS._serialized_end=1076
  _OPSGENIESETTINGS._serialized_start=1078
  _OPSGENIESETTINGS._serialized_end=1130
# @@protoc_insertion_point(module_scope)
