# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/user/v1/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.self_service.user.v1 import user_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_user__pb2
from _qwak_proto.qwak.self_service.user.v1 import api_key_pb2 as qwak_dot_self__service_dot_user_dot_v1_dot_api__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/self_service/user/v1/user_service.proto\x12\x19qwak.self_service.user.v1\x1a$qwak/self_service/user/v1/user.proto\x1a\'qwak/self_service/user/v1/api_key.proto\"O\n\x15GenerateApiKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\")\n\x16GenerateApiKeyResponse\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\">\n\x13RevokeApiKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\x8e\x01\n\x14RevokeApiKeyResponse\x12\x46\n\x06status\x18\x01 \x01(\x0e\x32\x36.qwak.self_service.user.v1.RevokeApiKeyResponse.Status\".\n\x06Status\x12\x17\n\x13INVALID_USER_STATUS\x10\x00\x12\x0b\n\x07REVOKED\x10\x01\"\x1a\n\x18ListApiKeyDetailsRequest\"\x86\x02\n\x19ListApiKeyDetailsResponse\x12|\n\x1e\x65nvironment_to_api_key_details\x18\x01 \x03(\x0b\x32T.qwak.self_service.user.v1.ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry\x1ak\n\x1f\x45nvironmentToApiKeyDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.qwak.self_service.user.v1.ApiKeyDetails:\x02\x38\x01\"\x17\n\x15GetUserProfileRequest\"V\n\x16GetUserProfileResponse\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"X\n\x18UpdateUserProfileRequest\x12<\n\x0cuser_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile\"a\n\x19UpdateUserProfileResponse\x12\x44\n\x14updated_user_profile\x18\x01 \x01(\x0b\x32&.qwak.self_service.user.v1.UserProfile2\xec\x04\n\x0bUserService\x12u\n\x0eGenerateApiKey\x12\x30.qwak.self_service.user.v1.GenerateApiKeyRequest\x1a\x31.qwak.self_service.user.v1.GenerateApiKeyResponse\x12o\n\x0cRevokeApiKey\x12..qwak.self_service.user.v1.RevokeApiKeyRequest\x1a/.qwak.self_service.user.v1.RevokeApiKeyResponse\x12~\n\x11ListApiKeyDetails\x12\x33.qwak.self_service.user.v1.ListApiKeyDetailsRequest\x1a\x34.qwak.self_service.user.v1.ListApiKeyDetailsResponse\x12u\n\x0eGetUserProfile\x12\x30.qwak.self_service.user.v1.GetUserProfileRequest\x1a\x31.qwak.self_service.user.v1.GetUserProfileResponse\x12~\n\x11UpdateUserProfile\x12\x33.qwak.self_service.user.v1.UpdateUserProfileRequest\x1a\x34.qwak.self_service.user.v1.UpdateUserProfileResponseB\xaf\x01\n\x1f\x63om.qwak.ai.self_service.v1.apiP\x01Z\x89\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/user/v1;self_service_user_v1b\x06proto3')



_GENERATEAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['GenerateApiKeyRequest']
_GENERATEAPIKEYRESPONSE = DESCRIPTOR.message_types_by_name['GenerateApiKeyResponse']
_REVOKEAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['RevokeApiKeyRequest']
_REVOKEAPIKEYRESPONSE = DESCRIPTOR.message_types_by_name['RevokeApiKeyResponse']
_LISTAPIKEYDETAILSREQUEST = DESCRIPTOR.message_types_by_name['ListApiKeyDetailsRequest']
_LISTAPIKEYDETAILSRESPONSE = DESCRIPTOR.message_types_by_name['ListApiKeyDetailsResponse']
_LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY = _LISTAPIKEYDETAILSRESPONSE.nested_types_by_name['EnvironmentToApiKeyDetailsEntry']
_GETUSERPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetUserProfileRequest']
_GETUSERPROFILERESPONSE = DESCRIPTOR.message_types_by_name['GetUserProfileResponse']
_UPDATEUSERPROFILEREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserProfileRequest']
_UPDATEUSERPROFILERESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserProfileResponse']
_REVOKEAPIKEYRESPONSE_STATUS = _REVOKEAPIKEYRESPONSE.enum_types_by_name['Status']
GenerateApiKeyRequest = _reflection.GeneratedProtocolMessageType('GenerateApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAPIKEYREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GenerateApiKeyRequest)
  })
_sym_db.RegisterMessage(GenerateApiKeyRequest)

GenerateApiKeyResponse = _reflection.GeneratedProtocolMessageType('GenerateApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEAPIKEYRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GenerateApiKeyResponse)
  })
_sym_db.RegisterMessage(GenerateApiKeyResponse)

RevokeApiKeyRequest = _reflection.GeneratedProtocolMessageType('RevokeApiKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAPIKEYREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.RevokeApiKeyRequest)
  })
_sym_db.RegisterMessage(RevokeApiKeyRequest)

RevokeApiKeyResponse = _reflection.GeneratedProtocolMessageType('RevokeApiKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _REVOKEAPIKEYRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.RevokeApiKeyResponse)
  })
_sym_db.RegisterMessage(RevokeApiKeyResponse)

ListApiKeyDetailsRequest = _reflection.GeneratedProtocolMessageType('ListApiKeyDetailsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPIKEYDETAILSREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsRequest)
  })
_sym_db.RegisterMessage(ListApiKeyDetailsRequest)

ListApiKeyDetailsResponse = _reflection.GeneratedProtocolMessageType('ListApiKeyDetailsResponse', (_message.Message,), {

  'EnvironmentToApiKeyDetailsEntry' : _reflection.GeneratedProtocolMessageType('EnvironmentToApiKeyDetailsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY,
    '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
    # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPIKEYDETAILSRESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.ListApiKeyDetailsResponse)
  })
_sym_db.RegisterMessage(ListApiKeyDetailsResponse)
_sym_db.RegisterMessage(ListApiKeyDetailsResponse.EnvironmentToApiKeyDetailsEntry)

GetUserProfileRequest = _reflection.GeneratedProtocolMessageType('GetUserProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERPROFILEREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GetUserProfileRequest)
  })
_sym_db.RegisterMessage(GetUserProfileRequest)

GetUserProfileResponse = _reflection.GeneratedProtocolMessageType('GetUserProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERPROFILERESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.GetUserProfileResponse)
  })
_sym_db.RegisterMessage(GetUserProfileResponse)

UpdateUserProfileRequest = _reflection.GeneratedProtocolMessageType('UpdateUserProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERPROFILEREQUEST,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.UpdateUserProfileRequest)
  })
_sym_db.RegisterMessage(UpdateUserProfileRequest)

UpdateUserProfileResponse = _reflection.GeneratedProtocolMessageType('UpdateUserProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERPROFILERESPONSE,
  '__module__' : 'qwak.self_service.user.v1.user_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.self_service.user.v1.UpdateUserProfileResponse)
  })
_sym_db.RegisterMessage(UpdateUserProfileResponse)

_USERSERVICE = DESCRIPTOR.services_by_name['UserService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.self_service.v1.apiP\001Z\211\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/user/v1;self_service_user_v1'
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._options = None
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_options = b'8\001'
  _GENERATEAPIKEYREQUEST._serialized_start=154
  _GENERATEAPIKEYREQUEST._serialized_end=233
  _GENERATEAPIKEYRESPONSE._serialized_start=235
  _GENERATEAPIKEYRESPONSE._serialized_end=276
  _REVOKEAPIKEYREQUEST._serialized_start=278
  _REVOKEAPIKEYREQUEST._serialized_end=340
  _REVOKEAPIKEYRESPONSE._serialized_start=343
  _REVOKEAPIKEYRESPONSE._serialized_end=485
  _REVOKEAPIKEYRESPONSE_STATUS._serialized_start=439
  _REVOKEAPIKEYRESPONSE_STATUS._serialized_end=485
  _LISTAPIKEYDETAILSREQUEST._serialized_start=487
  _LISTAPIKEYDETAILSREQUEST._serialized_end=513
  _LISTAPIKEYDETAILSRESPONSE._serialized_start=516
  _LISTAPIKEYDETAILSRESPONSE._serialized_end=778
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_start=671
  _LISTAPIKEYDETAILSRESPONSE_ENVIRONMENTTOAPIKEYDETAILSENTRY._serialized_end=778
  _GETUSERPROFILEREQUEST._serialized_start=780
  _GETUSERPROFILEREQUEST._serialized_end=803
  _GETUSERPROFILERESPONSE._serialized_start=805
  _GETUSERPROFILERESPONSE._serialized_end=891
  _UPDATEUSERPROFILEREQUEST._serialized_start=893
  _UPDATEUSERPROFILEREQUEST._serialized_end=981
  _UPDATEUSERPROFILERESPONSE._serialized_start=983
  _UPDATEUSERPROFILERESPONSE._serialized_end=1080
  _USERSERVICE._serialized_start=1083
  _USERSERVICE._serialized_end=1703
# @@protoc_insertion_point(module_scope)
