# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/entities/entity_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.entities import entity_pb2 as qwak_dot_feature__store_dot_entities_dot_entity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0qwak/feature_store/entities/entity_service.proto\x12\x1bqwak.feature.store.entities\x1a(qwak/feature_store/entities/entity.proto\"S\n\x13\x43reateEntityRequest\x12<\n\x0b\x65ntity_spec\x18\x01 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"f\n\x13UpdateEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\x12<\n\x0b\x65ntity_spec\x18\x02 \x01(\x0b\x32\'.qwak.feature.store.entities.EntitySpec\"K\n\x14UpdateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"K\n\x14\x43reateEntityResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\")\n\x14GetEntityByIdRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"L\n\x15GetEntityByIdResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"-\n\x16GetEntityByNameRequest\x12\x13\n\x0b\x65ntity_name\x18\x01 \x01(\t\"N\n\x17GetEntityByNameResponse\x12\x33\n\x06\x65ntity\x18\x01 \x01(\x0b\x32#.qwak.feature.store.entities.Entity\"(\n\x13\x44\x65leteEntityRequest\x12\x11\n\tentity_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteEntityResponse\"\x15\n\x13ListEntitiesRequest\"M\n\x14ListEntitiesResponse\x12\x35\n\x08\x65ntities\x18\x01 \x03(\x0b\x32#.qwak.feature.store.entities.Entity2\xd9\x05\n\rEntityService\x12s\n\x0c\x43reateEntity\x12\x30.qwak.feature.store.entities.CreateEntityRequest\x1a\x31.qwak.feature.store.entities.CreateEntityResponse\x12s\n\x0cUpdateEntity\x12\x30.qwak.feature.store.entities.UpdateEntityRequest\x1a\x31.qwak.feature.store.entities.UpdateEntityResponse\x12s\n\x0c\x44\x65leteEntity\x12\x30.qwak.feature.store.entities.DeleteEntityRequest\x1a\x31.qwak.feature.store.entities.DeleteEntityResponse\x12v\n\rGetEntityById\x12\x31.qwak.feature.store.entities.GetEntityByIdRequest\x1a\x32.qwak.feature.store.entities.GetEntityByIdResponse\x12|\n\x0fGetEntityByName\x12\x33.qwak.feature.store.entities.GetEntityByNameRequest\x1a\x34.qwak.feature.store.entities.GetEntityByNameResponse\x12s\n\x0cListEntities\x12\x30.qwak.feature.store.entities.ListEntitiesRequest\x1a\x31.qwak.feature.store.entities.ListEntitiesResponseB]\n(com.qwak.ai.feature.store.management.apiP\x01Z/qwak/featurestore/entities;featurestoreentitiesb\x06proto3')



_CREATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['CreateEntityRequest']
_UPDATEENTITYREQUEST = DESCRIPTOR.message_types_by_name['UpdateEntityRequest']
_UPDATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateEntityResponse']
_CREATEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['CreateEntityResponse']
_GETENTITYBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetEntityByIdRequest']
_GETENTITYBYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetEntityByIdResponse']
_GETENTITYBYNAMEREQUEST = DESCRIPTOR.message_types_by_name['GetEntityByNameRequest']
_GETENTITYBYNAMERESPONSE = DESCRIPTOR.message_types_by_name['GetEntityByNameResponse']
_DELETEENTITYREQUEST = DESCRIPTOR.message_types_by_name['DeleteEntityRequest']
_DELETEENTITYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteEntityResponse']
_LISTENTITIESREQUEST = DESCRIPTOR.message_types_by_name['ListEntitiesRequest']
_LISTENTITIESRESPONSE = DESCRIPTOR.message_types_by_name['ListEntitiesResponse']
CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

UpdateEntityResponse = _reflection.GeneratedProtocolMessageType('UpdateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.UpdateEntityResponse)
  })
_sym_db.RegisterMessage(UpdateEntityResponse)

CreateEntityResponse = _reflection.GeneratedProtocolMessageType('CreateEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.CreateEntityResponse)
  })
_sym_db.RegisterMessage(CreateEntityResponse)

GetEntityByIdRequest = _reflection.GeneratedProtocolMessageType('GetEntityByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYIDREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByIdRequest)
  })
_sym_db.RegisterMessage(GetEntityByIdRequest)

GetEntityByIdResponse = _reflection.GeneratedProtocolMessageType('GetEntityByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYIDRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByIdResponse)
  })
_sym_db.RegisterMessage(GetEntityByIdResponse)

GetEntityByNameRequest = _reflection.GeneratedProtocolMessageType('GetEntityByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYNAMEREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByNameRequest)
  })
_sym_db.RegisterMessage(GetEntityByNameRequest)

GetEntityByNameResponse = _reflection.GeneratedProtocolMessageType('GetEntityByNameResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYBYNAMERESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.GetEntityByNameResponse)
  })
_sym_db.RegisterMessage(GetEntityByNameResponse)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

DeleteEntityResponse = _reflection.GeneratedProtocolMessageType('DeleteEntityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.DeleteEntityResponse)
  })
_sym_db.RegisterMessage(DeleteEntityResponse)

ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'qwak.feature_store.entities.entity_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.entities.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

_ENTITYSERVICE = DESCRIPTOR.services_by_name['EntityService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.feature.store.management.apiP\001Z/qwak/featurestore/entities;featurestoreentities'
  _CREATEENTITYREQUEST._serialized_start=123
  _CREATEENTITYREQUEST._serialized_end=206
  _UPDATEENTITYREQUEST._serialized_start=208
  _UPDATEENTITYREQUEST._serialized_end=310
  _UPDATEENTITYRESPONSE._serialized_start=312
  _UPDATEENTITYRESPONSE._serialized_end=387
  _CREATEENTITYRESPONSE._serialized_start=389
  _CREATEENTITYRESPONSE._serialized_end=464
  _GETENTITYBYIDREQUEST._serialized_start=466
  _GETENTITYBYIDREQUEST._serialized_end=507
  _GETENTITYBYIDRESPONSE._serialized_start=509
  _GETENTITYBYIDRESPONSE._serialized_end=585
  _GETENTITYBYNAMEREQUEST._serialized_start=587
  _GETENTITYBYNAMEREQUEST._serialized_end=632
  _GETENTITYBYNAMERESPONSE._serialized_start=634
  _GETENTITYBYNAMERESPONSE._serialized_end=712
  _DELETEENTITYREQUEST._serialized_start=714
  _DELETEENTITYREQUEST._serialized_end=754
  _DELETEENTITYRESPONSE._serialized_start=756
  _DELETEENTITYRESPONSE._serialized_end=778
  _LISTENTITIESREQUEST._serialized_start=780
  _LISTENTITIESREQUEST._serialized_end=801
  _LISTENTITIESRESPONSE._serialized_start=803
  _LISTENTITIESRESPONSE._serialized_end=880
  _ENTITYSERVICE._serialized_start=883
  _ENTITYSERVICE._serialized_end=1612
# @@protoc_insertion_point(module_scope)
