"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ArtifactorySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_REGISTRY_PREFIX_FIELD_NUMBER: builtins.int
    INTERNAL_REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    AUTHENTICATION_DETAILS_FIELD_NUMBER: builtins.int
    container_registry_prefix: builtins.str
    internal_repository_name: builtins.str
    @property
    def authentication_details(self) -> global___ArtifactoryAuthenticationDetails: ...
    def __init__(
        self,
        *,
        container_registry_prefix: builtins.str = ...,
        internal_repository_name: builtins.str = ...,
        authentication_details: global___ArtifactoryAuthenticationDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authentication_details", b"authentication_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authentication_details", b"authentication_details", "container_registry_prefix", b"container_registry_prefix", "internal_repository_name", b"internal_repository_name"]) -> None: ...

global___ArtifactorySettings = ArtifactorySettings

class ArtifactoryAuthenticationDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    token: builtins.str
    username: builtins.str
    tenant_id: builtins.str
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        username: builtins.str = ...,
        tenant_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tenant_id", b"tenant_id", "token", b"token", "username", b"username"]) -> None: ...

global___ArtifactoryAuthenticationDetails = ArtifactoryAuthenticationDetails
