# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/alert_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import alert_pb2 as qwak_dot_deployment_dot_alert__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/deployment/alert_service.proto\x12\x1aqwak.deployment.management\x1a\x1bqwak/deployment/alert.proto\"`\n\x1dGetAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x03 \x01(\t\"W\n\x1eGetAlertsConfigurationResponse\x12\x35\n\x06\x61lerts\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\"\xad\x01\n\x1f\x41pplyAlertsConfigurationRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x35\n\x06\x61lerts\x18\x03 \x03(\x0b\x32%.qwak.deployment.management.AlertRule\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\"\"\n ApplyAlertsConfigurationResponse\"<\n\"GetNotificationChannelsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"y\n#GetNotificationChannelsListResponse\x12R\n\x15notification_channels\x18\x01 \x03(\x0b\x32\x33.qwak.deployment.management.NotificationChannelSpec\"\x88\x01\n\x1f\x41pplyNotificationChannelRequest\x12M\n\x14notification_channel\x18\x01 \x01(\x0b\x32/.qwak.deployment.management.NotificationChannel\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"\"\n ApplyNotificationChannelResponse\"[\n DeleteNotificationChannelRequest\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\"#\n!DeleteNotificationChannelResponse\"B\n(GetNotificationChannelDetailsListRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"{\n)GetNotificationChannelDetailsListResponse\x12N\n\x15notification_channels\x18\x01 \x03(\x0b\x32/.qwak.deployment.management.NotificationChannel2\xc9\x07\n\x16\x41lertManagementService\x12\x8f\x01\n\x16GetAlertsConfiguration\x12\x39.qwak.deployment.management.GetAlertsConfigurationRequest\x1a:.qwak.deployment.management.GetAlertsConfigurationResponse\x12\x95\x01\n\x18\x41pplyAlertsConfiguration\x12;.qwak.deployment.management.ApplyAlertsConfigurationRequest\x1a<.qwak.deployment.management.ApplyAlertsConfigurationResponse\x12\x9e\x01\n\x1bGetNotificationChannelsList\x12>.qwak.deployment.management.GetNotificationChannelsListRequest\x1a?.qwak.deployment.management.GetNotificationChannelsListResponse\x12\x95\x01\n\x18\x41pplyNotificationChannel\x12;.qwak.deployment.management.ApplyNotificationChannelRequest\x1a<.qwak.deployment.management.ApplyNotificationChannelResponse\x12\x98\x01\n\x19\x44\x65leteNotificationChannel\x12<.qwak.deployment.management.DeleteNotificationChannelRequest\x1a=.qwak.deployment.management.DeleteNotificationChannelResponse\x12\xb0\x01\n!GetNotificationChannelDetailsList\x12\x44.qwak.deployment.management.GetNotificationChannelDetailsListRequest\x1a\x45.qwak.deployment.management.GetNotificationChannelDetailsListResponseB)\n%com.qwak.ai.management.deployment.apiP\x01\x62\x06proto3')



_GETALERTSCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['GetAlertsConfigurationRequest']
_GETALERTSCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['GetAlertsConfigurationResponse']
_APPLYALERTSCONFIGURATIONREQUEST = DESCRIPTOR.message_types_by_name['ApplyAlertsConfigurationRequest']
_APPLYALERTSCONFIGURATIONRESPONSE = DESCRIPTOR.message_types_by_name['ApplyAlertsConfigurationResponse']
_GETNOTIFICATIONCHANNELSLISTREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationChannelsListRequest']
_GETNOTIFICATIONCHANNELSLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetNotificationChannelsListResponse']
_APPLYNOTIFICATIONCHANNELREQUEST = DESCRIPTOR.message_types_by_name['ApplyNotificationChannelRequest']
_APPLYNOTIFICATIONCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['ApplyNotificationChannelResponse']
_DELETENOTIFICATIONCHANNELREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotificationChannelRequest']
_DELETENOTIFICATIONCHANNELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotificationChannelResponse']
_GETNOTIFICATIONCHANNELDETAILSLISTREQUEST = DESCRIPTOR.message_types_by_name['GetNotificationChannelDetailsListRequest']
_GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE = DESCRIPTOR.message_types_by_name['GetNotificationChannelDetailsListResponse']
GetAlertsConfigurationRequest = _reflection.GeneratedProtocolMessageType('GetAlertsConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTSCONFIGURATIONREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetAlertsConfigurationRequest)
  })
_sym_db.RegisterMessage(GetAlertsConfigurationRequest)

GetAlertsConfigurationResponse = _reflection.GeneratedProtocolMessageType('GetAlertsConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTSCONFIGURATIONRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetAlertsConfigurationResponse)
  })
_sym_db.RegisterMessage(GetAlertsConfigurationResponse)

ApplyAlertsConfigurationRequest = _reflection.GeneratedProtocolMessageType('ApplyAlertsConfigurationRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYALERTSCONFIGURATIONREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyAlertsConfigurationRequest)
  })
_sym_db.RegisterMessage(ApplyAlertsConfigurationRequest)

ApplyAlertsConfigurationResponse = _reflection.GeneratedProtocolMessageType('ApplyAlertsConfigurationResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYALERTSCONFIGURATIONRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyAlertsConfigurationResponse)
  })
_sym_db.RegisterMessage(ApplyAlertsConfigurationResponse)

GetNotificationChannelsListRequest = _reflection.GeneratedProtocolMessageType('GetNotificationChannelsListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELSLISTREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelsListRequest)
  })
_sym_db.RegisterMessage(GetNotificationChannelsListRequest)

GetNotificationChannelsListResponse = _reflection.GeneratedProtocolMessageType('GetNotificationChannelsListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELSLISTRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelsListResponse)
  })
_sym_db.RegisterMessage(GetNotificationChannelsListResponse)

ApplyNotificationChannelRequest = _reflection.GeneratedProtocolMessageType('ApplyNotificationChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYNOTIFICATIONCHANNELREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyNotificationChannelRequest)
  })
_sym_db.RegisterMessage(ApplyNotificationChannelRequest)

ApplyNotificationChannelResponse = _reflection.GeneratedProtocolMessageType('ApplyNotificationChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYNOTIFICATIONCHANNELRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.ApplyNotificationChannelResponse)
  })
_sym_db.RegisterMessage(ApplyNotificationChannelResponse)

DeleteNotificationChannelRequest = _reflection.GeneratedProtocolMessageType('DeleteNotificationChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFICATIONCHANNELREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.DeleteNotificationChannelRequest)
  })
_sym_db.RegisterMessage(DeleteNotificationChannelRequest)

DeleteNotificationChannelResponse = _reflection.GeneratedProtocolMessageType('DeleteNotificationChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFICATIONCHANNELRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.DeleteNotificationChannelResponse)
  })
_sym_db.RegisterMessage(DeleteNotificationChannelResponse)

GetNotificationChannelDetailsListRequest = _reflection.GeneratedProtocolMessageType('GetNotificationChannelDetailsListRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelDetailsListRequest)
  })
_sym_db.RegisterMessage(GetNotificationChannelDetailsListRequest)

GetNotificationChannelDetailsListResponse = _reflection.GeneratedProtocolMessageType('GetNotificationChannelDetailsListResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE,
  '__module__' : 'qwak.deployment.alert_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.deployment.management.GetNotificationChannelDetailsListResponse)
  })
_sym_db.RegisterMessage(GetNotificationChannelDetailsListResponse)

_ALERTMANAGEMENTSERVICE = DESCRIPTOR.services_by_name['AlertManagementService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001'
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _GETALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._options = None
  _APPLYALERTSCONFIGURATIONREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETALERTSCONFIGURATIONREQUEST._serialized_start=96
  _GETALERTSCONFIGURATIONREQUEST._serialized_end=192
  _GETALERTSCONFIGURATIONRESPONSE._serialized_start=194
  _GETALERTSCONFIGURATIONRESPONSE._serialized_end=281
  _APPLYALERTSCONFIGURATIONREQUEST._serialized_start=284
  _APPLYALERTSCONFIGURATIONREQUEST._serialized_end=457
  _APPLYALERTSCONFIGURATIONRESPONSE._serialized_start=459
  _APPLYALERTSCONFIGURATIONRESPONSE._serialized_end=493
  _GETNOTIFICATIONCHANNELSLISTREQUEST._serialized_start=495
  _GETNOTIFICATIONCHANNELSLISTREQUEST._serialized_end=555
  _GETNOTIFICATIONCHANNELSLISTRESPONSE._serialized_start=557
  _GETNOTIFICATIONCHANNELSLISTRESPONSE._serialized_end=678
  _APPLYNOTIFICATIONCHANNELREQUEST._serialized_start=681
  _APPLYNOTIFICATIONCHANNELREQUEST._serialized_end=817
  _APPLYNOTIFICATIONCHANNELRESPONSE._serialized_start=819
  _APPLYNOTIFICATIONCHANNELRESPONSE._serialized_end=853
  _DELETENOTIFICATIONCHANNELREQUEST._serialized_start=855
  _DELETENOTIFICATIONCHANNELREQUEST._serialized_end=946
  _DELETENOTIFICATIONCHANNELRESPONSE._serialized_start=948
  _DELETENOTIFICATIONCHANNELRESPONSE._serialized_end=983
  _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST._serialized_start=985
  _GETNOTIFICATIONCHANNELDETAILSLISTREQUEST._serialized_end=1051
  _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE._serialized_start=1053
  _GETNOTIFICATIONCHANNELDETAILSLISTRESPONSE._serialized_end=1176
  _ALERTMANAGEMENTSERVICE._serialized_start=1179
  _ALERTMANAGEMENTSERVICE._serialized_end=2148
# @@protoc_insertion_point(module_scope)
