# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.secret_service import secret_service_pb2 as qwak_dot_secret__service_dot_secret__service__pb2


class SecretServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/SetSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.FromString,
                )
        self.GetSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/GetSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.FromString,
                )
        self.DeleteSecret = channel.unary_unary(
                '/qwak.secret.service.SecretService/DeleteSecret',
                request_serializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
                response_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.FromString,
                )


class SecretServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SetSecret(self, request, context):
        """Set a value for a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecret(self, request, context):
        """Get a secret value
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSecret(self, request, context):
        """Remove a secret
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.SerializeToString,
            ),
            'GetSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.SerializeToString,
            ),
            'DeleteSecret': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSecret,
                    request_deserializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.FromString,
                    response_serializer=qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.secret.service.SecretService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/SetSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.SetSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.SetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/GetSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.GetSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.GetSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSecret(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.secret.service.SecretService/DeleteSecret',
            qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretRequest.SerializeToString,
            qwak_dot_secret__service_dot_secret__service__pb2.DeleteSecretResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
