"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.workspace.workspace_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_SPEC_FIELD_NUMBER: builtins.int
    @property
    def workspace_spec(self) -> qwak.workspace.workspace_pb2.WorkspaceSpec:
        """Workspace spec"""
    def __init__(
        self,
        *,
        workspace_spec: qwak.workspace.workspace_pb2.WorkspaceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> None: ...

global___CreateWorkspaceRequest = CreateWorkspaceRequest

class CreateWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___CreateWorkspaceResponse = CreateWorkspaceResponse

class UpdateWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    WORKSPACE_SPEC_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def workspace_spec(self) -> qwak.workspace.workspace_pb2.WorkspaceSpec:
        """Workspace spec"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        workspace_spec: qwak.workspace.workspace_pb2.WorkspaceSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace_spec", b"workspace_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id", "workspace_spec", b"workspace_spec"]) -> None: ...

global___UpdateWorkspaceRequest = UpdateWorkspaceRequest

class DeployWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___DeployWorkspaceRequest = DeployWorkspaceRequest

class DeployWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeployWorkspaceResponse = DeployWorkspaceResponse

class UndeployWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___UndeployWorkspaceRequest = UndeployWorkspaceRequest

class UndeployWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UndeployWorkspaceResponse = UndeployWorkspaceResponse

class UpdateWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateWorkspaceResponse = UpdateWorkspaceResponse

class ListWorkspacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListWorkspacesRequest = ListWorkspacesRequest

class ListWorkspacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACES_FIELD_NUMBER: builtins.int
    @property
    def workspaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.workspace.workspace_pb2.Workspace]:
        """List of workspaces"""
    def __init__(
        self,
        *,
        workspaces: collections.abc.Iterable[qwak.workspace.workspace_pb2.Workspace] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspaces", b"workspaces"]) -> None: ...

global___ListWorkspacesResponse = ListWorkspacesResponse

class GetWorkspaceByIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___GetWorkspaceByIdRequest = GetWorkspaceByIdRequest

class GetWorkspaceByIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_FIELD_NUMBER: builtins.int
    @property
    def workspace(self) -> qwak.workspace.workspace_pb2.Workspace:
        """Workspace details"""
    def __init__(
        self,
        *,
        workspace: qwak.workspace.workspace_pb2.Workspace | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["workspace", b"workspace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace", b"workspace"]) -> None: ...

global___GetWorkspaceByIdResponse = GetWorkspaceByIdResponse

class DeleteWorkspaceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_id", b"workspace_id"]) -> None: ...

global___DeleteWorkspaceRequest = DeleteWorkspaceRequest

class DeleteWorkspaceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteWorkspaceResponse = DeleteWorkspaceResponse

class UpdateWorkspaceStatusFromEdgeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_WORKSPACE_STATUS_FROM_EDGE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def update_workspace_status_from_edge_details(self) -> qwak.workspace.workspace_pb2.UpdateWorkspaceStatusFromEdgeDetails: ...
    def __init__(
        self,
        *,
        update_workspace_status_from_edge_details: qwak.workspace.workspace_pb2.UpdateWorkspaceStatusFromEdgeDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["update_workspace_status_from_edge_details", b"update_workspace_status_from_edge_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["update_workspace_status_from_edge_details", b"update_workspace_status_from_edge_details"]) -> None: ...

global___UpdateWorkspaceStatusFromEdgeRequest = UpdateWorkspaceStatusFromEdgeRequest

class UpdateWorkspaceStatusFromEdgeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateWorkspaceStatusFromEdgeResponse = UpdateWorkspaceStatusFromEdgeResponse

class RegisterWorkspaceTagRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Tag name"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tags", b"tags", "workspace_id", b"workspace_id"]) -> None: ...

global___RegisterWorkspaceTagRequest = RegisterWorkspaceTagRequest

class RegisterWorkspaceTagResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterWorkspaceTagResponse = RegisterWorkspaceTagResponse

class ListWorkspaceImagesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListWorkspaceImagesRequest = ListWorkspaceImagesRequest

class ListWorkspaceImagesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_IMAGES_FIELD_NUMBER: builtins.int
    @property
    def workspace_images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.workspace.workspace_pb2.WorkspaceImage]:
        """List of workspace images"""
    def __init__(
        self,
        *,
        workspace_images: collections.abc.Iterable[qwak.workspace.workspace_pb2.WorkspaceImage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["workspace_images", b"workspace_images"]) -> None: ...

global___ListWorkspaceImagesResponse = ListWorkspaceImagesResponse

class CountWorkspacesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CountWorkspacesRequest = CountWorkspacesRequest

class CountWorkspacesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    count: builtins.int
    """Count of workspaces"""
    def __init__(
        self,
        *,
        count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count"]) -> None: ...

global___CountWorkspacesResponse = CountWorkspacesResponse

class GetDefaultWorkspaceValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDefaultWorkspaceValuesRequest = GetDefaultWorkspaceValuesRequest

class GetDefaultWorkspaceValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_WORKSPACE_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def default_workspace_details(self) -> qwak.workspace.workspace_pb2.DefaultWorkspaceDetails: ...
    def __init__(
        self,
        *,
        default_workspace_details: qwak.workspace.workspace_pb2.DefaultWorkspaceDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_workspace_details", b"default_workspace_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_workspace_details", b"default_workspace_details"]) -> None: ...

global___GetDefaultWorkspaceValuesResponse = GetDefaultWorkspaceValuesResponse

class MarkBuildAsCopiedRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    build_id: builtins.str
    """Build id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "workspace_id", b"workspace_id"]) -> None: ...

global___MarkBuildAsCopiedRequest = MarkBuildAsCopiedRequest

class MarkBuildAsCopiedResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MarkBuildAsCopiedResponse = MarkBuildAsCopiedResponse

class CopyBuildRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WORKSPACE_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    workspace_id: builtins.str
    """Workspace id"""
    build_id: builtins.str
    """Build id"""
    def __init__(
        self,
        *,
        workspace_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "workspace_id", b"workspace_id"]) -> None: ...

global___CopyBuildRequest = CopyBuildRequest

class CopyBuildResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CopyBuildResponse = CopyBuildResponse
